DocuTranslate - 交互式文档翻译

#### DocuTranslate

##

自动选择工作流

##

插入模式
选择如何将翻译后的文本插入。
分隔符
当插入模式为附加或前置时，用于分隔原文和译文的字符。`\n` 代表换行。

##

插入模式
选择如何将翻译后的文本插入到单元格中。
分隔符
当插入模式为附加或前置时，用于分隔原文和译文的字符。`\n` 代表换行。

##

插入模式
选择如何将翻译后的文本插入。
分隔符
当插入模式为附加或前置时，用于分隔原文和译文的字符。`\n` 代表换行。

##

插入模式
选择如何将翻译后的文本插入。
分隔符
当插入模式为附加或前置时，用于分隔原文和译文的字符。`\n` 代表换行。

##

需要翻译的JSON路径
采用`jsonpath-ng`的路径选择语法，每一行表示一个json路径

##

解析引擎
如果上传的文件本身是.md格式，此项可不选。
Mineru Token
公式识别
代码识别

##

选择平台
API 地址 (Base URL)
API Key
模型 ID

##

目标语言
思考模式
启用 禁用 默认
自定义Prompt

##

分块大小:
并发数:
Temperature:

GitHub主页(欢迎star❤):
https://github.com/xunbu/docutranslate

交流QQ群: 1047781902

#### 任务列表

当前没有任务，点击“新建任务”开始吧！

##### 预览

###### 原文

###### 译文

##### 使用教程

视频教程可以在B站搜索 docutranslate 获取。

欢迎使用 DocuTranslate！请按照以下步骤完成文档翻译：

1. 选择工作流

   首先，在配置面板顶部选择您需要的翻译流程。不同的工作流适用于不同类型的文件：

   - 转Markdown再翻译: 适用于翻译PDF、markdown、图片等文件。
   - 纯文本翻译: 用于翻译 `.txt` 等纯文本文件。
   - JSON翻译: 用于翻译 `.json` 文件中的特定字段。
   - DOCX翻译: 用于翻译 `.docx` 文件。
   - XLSX翻译: 用于翻译 `.xlsx` 电子表格文件。
   - SRT字幕翻译: 用于翻译 `.srt` 字幕文件。
   - EPUB翻译: 用于翻译 `.epub` 电子书文件。
   新增功能: "自动选择工作流"开关已默认开启。您只需上传文件，系统会自动为您匹配合适的工作流，简化操作。
2. 配置参数

   根据您选择的工作流，完成相应的配置。所有配置项都会自动保存在您的浏览器中。

   - 解析配置 (仅在“转Markdown再翻译”工作流下显示):
     - 解析引擎: 选择一个引擎将您的文件（如PDF）转换为适合翻译的Markdown格式。如果您的文件已经是Markdown格式，则无需选择。
     - Mineru Token: 如果您选择 `minerU` 引擎，需要在此处填入您的Token。
   - DOCX/XLSX/SRT/EPUB翻译选项 (在对应工作流下显示):
     - 插入模式: 定义翻译结果如何放入文档或字幕。您可以选择直接“替换”原文，或是在原文之后“附加”，或是在原文之前“前置”。
     - 分隔符: 当选择“附加”或“前置”模式时，此项用于在原文和译文之间插入分隔符。
   - JSON路径配置 (仅在“JSON翻译”工作流下显示):
     - 需要翻译的JSON路径: 每行输入一个 JSONPath 表达式，指定需要翻译的字段。
     - 例如:`$..description`翻译所有键为description的值。`$.items[0].name`翻译第一个item的name值。
   - 翻译模型:
     - 选择平台/API 地址/API Key/模型 ID: 配置您希望使用的AI翻译服务。
     - 模型ID参考平台文档，建议使用非推理模型或混合推理模型（关闭思考）。
   - 翻译配置:
     - 目标语言/自定义Prompt: 指定翻译的目标语言和附加指令。
     - 思考模式:设置混合推理模型是否进行思考，目前支持智谱的glm4.5系列、阿里云的qwen3系列、火山引擎的seed1.6系列，建议选择禁用思考。
   - 高级参数:
     - 分块大小/并发数/Temperature: 发给ai的分块大小、并发请求数和温度，通常保持默认即可。
3. 上传文件

   在右侧的任务列表中，点击或拖拽您的文档到文件上传区域。

4. 开始翻译

   文件选择成功后，点击任务卡片右下角的 开始翻译 按钮。系统将开始处理任务，您可以在日志区域查看实时进度。

5. 查看与下载

   翻译完成后，任务卡片下方会出现操作按钮：

   - 预览: 在右侧滑出的面板中进行原文和译文的对照预览（仅作参考）。
   - 下载: 下载包括 PDF, DOCX, XLSX, HTML, Markdown 等多种格式的译文。

提示: 所有配置都会自动保存在您的浏览器本地，方便下次使用。

##### 感谢贡献

DocuTranslate是一个开源项目！大家的需求与使用是项目进步的动力。

感谢所有资助项目、提交代码与宝贵建议及给项目star的朋友们！

欢迎通过以下方式参与贡献：

github 主页 提交 Pull Request 报告 Issue

或者通过QQ群联系作者：1047781902